require 'solstice/version'
require 'solstice/engine'
module Solstice
  class << self
    def load!
      register_compass_extension if compass?
      if rails?
        register_rails_engine
      elsif lotus?
        register_lotus
      elsif sprockets?
        register_sprockets
      end
      configure_sass
    end
    def gem_path
      @gem_path ||= File.expand_path '..', File.dirname(__FILE__)
    end
    def stylesheets_path
      File.join assets_path, 'stylesheets'
    end
    def fonts_path
      File.join assets_path, 'fonts'
    end
    def javascripts_path
      File.join assets_path, 'javascripts'
    end
    def assets_path
      @assets_path ||= File.join gem_path, 'assets'
    end
    def sprockets?
      defined?(::Sprockets)
    end
    def compass?
      defined?(::Compass::Frameworks)
    end
    def rails?
      defined?(::Rails)
    end
    def lotus?
      defined?(::Lotus)
    end
    private
    def configure_sass
      require 'sass'
      ::Sass.load_paths << stylesheets_path
      ::Sass::Script::Number.precision = [8, ::Sass::Script::Number.precision].max
    end
    def register_compass_extension
      ::Compass::Frameworks.register(
          'solstice',
          :version               => Solstice::VERSION,
          :path                  => gem_path,
          :stylesheets           => stylesheets_path,
          :templates             => File.join(gem_path, 'templates')
      )
    end
    def register_lotus
      Lotus::Assets.sources << assets
    end
    def register_sprockets
      Sprockets.append_path(stylesheets_path)
      Sprockets.append_path(fonts_path)
      Sprockets.append_path(javascripts_path)
    end
  end
end

Solstice.load!